@@ -13,31 +13,43 @@
 #
 # Copyright Buildbot Team Members
 
-import sys
-import re
 import os
-import time
+import re
 import signal
+import sys
+import time
 
+from mock import Mock
+
+from twisted.internet import defer
+from twisted.internet import reactor
+from twisted.internet import task
+from twisted.python import log
+from twisted.python import runtime
+from twisted.python import util
 from twisted.trial import unittest
-from twisted.internet import task, defer, reactor
-from twisted.python import runtime, util, log
 
-from buildslave.test.util.misc import nl, BasedirMixin
-from buildslave.test.util import compat
-from buildslave.test.fake.slavebuilder import FakeSlaveBuilder
+from buildslave import runprocess
+from buildslave import util as bsutil
 from buildslave.exceptions import AbandonChain
-from buildslave import runprocess, util as bsutil
+from buildslave.test.fake.slavebuilder import FakeSlaveBuilder
+from buildslave.test.util import compat
+from buildslave.test.util.misc import BasedirMixin
+from buildslave.test.util.misc import nl
+
 
 def stdoutCommand(output):
     return [sys.executable, '-c', 'import sys; sys.stdout.write("%s\\n")' % output]
 
+
 def stderrCommand(output):
     return [sys.executable, '-c', 'import sys; sys.stderr.write("%s\\n")' % output]
 
+
 def sleepCommand(dur):
     return [sys.executable, '-c', 'import time; time.sleep(%d)' % dur]
 
+
 def scriptCommand(function, *args):
     runprocess_scripts = util.sibpath(__file__, 'runprocess-scripts.py')
     return [sys.executable, runprocess_scripts, function] + list(args)
@@ -45,13 +57,15 @@ def scriptCommand(function, *args):
 # windows returns rc 1, because exit status cannot indicate "signalled";
 # posix returns rc -1 for "signalled"
 FATAL_RC = -1
-if runtime.platformType  == 'win32':
+if runtime.platformType == 'win32':
     FATAL_RC = 1
 
 # We would like to see debugging output in the test.log
 runprocess.RunProcessPP.debug = True
 
+
 class TestRunProcess(BasedirMixin, unittest.TestCase):
+
     def setUp(self):
         self.setUpBasedir()
 
@@ -66,15 +80,15 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
 
     def testCommandEncodingList(self):
         b = FakeSlaveBuilder(False, self.basedir)
-        s = runprocess.RunProcess(b, [ u'abcd', 'efg' ], self.basedir)
+        s = runprocess.RunProcess(b, [u'abcd', 'efg'], self.basedir)
         self.assertIsInstance(s.command[0], str)
         self.assertIsInstance(s.fake_command[0], str)
 
     def testCommandEncodingObfuscated(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b,
-                        [ bsutil.Obfuscated(u'abcd', u'ABCD') ],
-                        self.basedir)
+                                  [bsutil.Obfuscated(u'abcd', u'ABCD')],
+                                  self.basedir)
         self.assertIsInstance(s.command[0], str)
         self.assertIsInstance(s.fake_command[0], str)
 
@@ -83,6 +97,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir)
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('hello\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -94,6 +109,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir, sendStdout=False)
 
         d = s.start()
+
         def check(ign):
             self.failIf({'stdout': nl('hello\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -105,6 +121,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir, keepStdout=True)
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('hello\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -117,6 +134,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stderrCommand("hello"), self.basedir)
 
         d = s.start()
+
         def check(ign):
             self.failIf({'stderr': nl('hello\n')} not in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -128,6 +146,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stderrCommand("hello"), self.basedir, sendStderr=False)
 
         d = s.start()
+
         def check(ign):
             self.failIf({'stderr': nl('hello\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -139,6 +158,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stderrCommand("hello"), self.basedir, keepStderr=True)
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stderr': nl('hello\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -152,12 +172,21 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, 'echo hello', self.basedir)
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('hello\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
         d.addCallback(check)
         return d
 
+    def testObfuscatedCommand(self):
+        b = FakeSlaveBuilder(False, self.basedir)
+        s = runprocess.RunProcess(b,
+                                  [('obfuscated', 'abcd', 'ABCD')],
+                                  self.basedir)
+        self.assertEqual(s.command, ['abcd'])
+        self.assertEqual(s.fake_command, ['ABCD'])
+
     def testMultiWordStringCommand(self):
         b = FakeSlaveBuilder(False, self.basedir)
         # careful!  This command must execute the same on windows and UNIX
@@ -167,6 +196,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         # no quoting occurs
         exp = nl('Happy Days and Jubilation\n')
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': exp} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -186,6 +216,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         else:
             exp = nl('Happy Days and Jubilation\n')
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': exp} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
@@ -206,61 +237,74 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
             exp = nl('Happy Days and Jubilation\n')
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': exp} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
         d.addCallback(check)
         return d
 
-    @compat.skipUnlessPlatformIs("win32")
-    def testPipeEmbedded(self):
+    def testPunctuation(self):
+        # make sure special characters make it through unscathed
         b = FakeSlaveBuilder(False, self.basedir)
-        s = runprocess.RunProcess(b, ['echo', 'escaped|pipe'],
+        punct = r'''!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~'''
+        s = runprocess.RunProcess(b, ['echo', punct, '%PATH%'],
                                   self.basedir)
 
         d = s.start()
+
+        if runtime.platformType == "win32":
+            # Windows echo doesn't parse arguments, so they remain
+            # quoted/escaped
+            out_punct = '"' + punct.replace('"', r'\"') + '"'
+        else:
+            out_punct = punct
+
         def check(ign):
-            self.failUnless({'stdout': nl('escaped|pipe\n')} in b.updates, b.show())
+            self.failUnless({'stdout': nl(out_punct + ' %PATH%\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
         d.addCallback(check)
-        return d        
+        return d
 
     @compat.skipUnlessPlatformIs("win32")
     def testPipeAlone(self):
         b = FakeSlaveBuilder(False, self.basedir)
-        #this is highly contrived, but it proves the point.
+        # this is highly contrived, but it proves the point.
         cmd = stdoutCommand("b\\na")
-        cmd[0] = cmd[0].replace(".exe","")
-        cmd.extend(['|','sort'])
+        cmd[0] = cmd[0].replace(".exe", "")
+        cmd.extend(['|', 'sort'])
         s = runprocess.RunProcess(b, cmd, self.basedir)
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('a\nb\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
         d.addCallback(check)
         return d
-    
+
     @compat.skipUnlessPlatformIs("win32")
     def testPipeString(self):
         b = FakeSlaveBuilder(False, self.basedir)
-        #this is highly contrived, but it proves the point.
+        # this is highly contrived, but it proves the point.
         cmd = sys.executable + ' -c "import sys; sys.stdout.write(\'b\\na\\n\')" | sort'
         s = runprocess.RunProcess(b, cmd, self.basedir)
 
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('a\nb\n')} in b.updates, b.show())
             self.failUnless({'rc': 0} in b.updates, b.show())
         d.addCallback(check)
         return d
-    
+
     def testCommandTimeout(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b, sleepCommand(10), self.basedir, timeout=5)
         clock = task.Clock()
         s._reactor = clock
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('hello\n')} not in b.updates, b.show())
             self.failUnless({'rc': FATAL_RC} in b.updates, b.show())
@@ -274,22 +318,24 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         clock = task.Clock()
         s._reactor = clock
         d = s.start()
+
         def check(ign):
             self.failUnless({'stdout': nl('hello\n')} not in b.updates, b.show())
             self.failUnless({'rc': FATAL_RC} in b.updates, b.show())
         d.addCallback(check)
-        clock.advance(6) # should knock out maxTime
+        clock.advance(6)  # should knock out maxTime
         return d
 
     @compat.skipUnlessPlatformIs("posix")
     def test_stdin_closed(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b,
-                scriptCommand('assert_stdin_closed'),
-                self.basedir,
-                usePTY=False, # if usePTY=True, stdin is never closed
-                logEnviron=False)
+                                  scriptCommand('assert_stdin_closed'),
+                                  self.basedir,
+                                  usePTY=False,  # if usePTY=True, stdin is never closed
+                                  logEnviron=False)
         d = s.start()
+
         def check(ign):
             self.failUnless({'rc': 0} in b.updates, b.show())
         d.addCallback(check)
@@ -306,6 +352,7 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s._startCommand = _startCommand
 
         d = s.start()
+
         def check(err):
             err.trap(AbandonChain)
             stderr = []
@@ -317,17 +364,18 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
             stderr = "".join(stderr)
             self.failUnless("RuntimeError" in stderr, stderr)
         d.addBoth(check)
-        d.addBoth(lambda _ : self.flushLoggedErrors())
+        d.addBoth(lambda _: self.flushLoggedErrors())
         return d
 
     def testLogEnviron(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
-                            environ={"FOO": "BAR"})
+                                  environ={"FOO": "BAR"})
 
         d = s.start()
+
         def check(ign):
-            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"] ])
+            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"]])
             self.failUnless("FOO=BAR" in headers, "got:\n" + headers)
         d.addCallback(check)
         return d
@@ -335,11 +383,12 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
     def testNoLogEnviron(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
-                            environ={"FOO": "BAR"}, logEnviron=False)
+                                  environ={"FOO": "BAR"}, logEnviron=False)
 
         d = s.start()
+
         def check(ign):
-            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"] ])
+            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"]])
             self.failUnless("FOO=BAR" not in headers, "got:\n" + headers)
         d.addCallback(check)
         return d
@@ -352,35 +401,38 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir, environ=environ)
 
         d = s.start()
+
         def check(ign):
-            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"] ])
+            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"]])
             self.failUnless("EXPND=-$" not in headers, "got:\n" + headers)
             self.failUnless("DOESNT_FIND=--" in headers, "got:\n" + headers)
-            self.failUnless("DOESNT_EXPAND=-${---}-"  in headers, "got:\n" + headers)
+            self.failUnless("DOESNT_EXPAND=-${---}-" in headers, "got:\n" + headers)
         d.addCallback(check)
         return d
 
     def testUnsetEnvironVar(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
-                            environ={"PATH":None})
+                                  environ={"PATH": None})
 
         d = s.start()
+
         def check(ign):
-            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"] ])
-            self.failUnless(not re.match('\bPATH=',headers), "got:\n" + headers)
+            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"]])
+            self.failUnless(not re.match('\bPATH=', headers), "got:\n" + headers)
         d.addCallback(check)
         return d
 
     def testEnvironPythonPath(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
-                            environ={"PYTHONPATH":'a'})
+                                  environ={"PYTHONPATH": 'a'})
 
         d = s.start()
+
         def check(ign):
-            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"] ])
-            self.failUnless(not re.match('\bPYTHONPATH=a%s' % (os.pathsep),headers),
+            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"]])
+            self.failUnless(not re.match('\bPYTHONPATH=a%s' % (os.pathsep), headers),
                             "got:\n" + headers)
         d.addCallback(check)
         return d
@@ -388,21 +440,22 @@ class TestRunProcess(BasedirMixin, unittest.TestCase):
     def testEnvironArray(self):
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
-                            environ={"FOO":['a', 'b']})
+                                  environ={"FOO": ['a', 'b']})
 
         d = s.start()
+
         def check(ign):
-            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"] ])
-            self.failUnless(not re.match('\bFOO=a%sb\b' % (os.pathsep),headers),
+            headers = "".join([update.values()[0] for update in b.updates if update.keys() == ["header"]])
+            self.failUnless(not re.match('\bFOO=a%sb\b' % (os.pathsep), headers),
                             "got:\n" + headers)
         d.addCallback(check)
         return d
 
     def testEnvironInt(self):
         b = FakeSlaveBuilder(False, self.basedir)
-        self.assertRaises(RuntimeError, lambda :
-            runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
-                            environ={"BUILD_NUMBER":13}))
+        self.assertRaises(RuntimeError, lambda:
+                          runprocess.RunProcess(b, stdoutCommand('hello'), self.basedir,
+                                                environ={"BUILD_NUMBER": 13}))
 
 
 class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
@@ -417,12 +470,16 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
     def tearDown(self):
         # make sure all of the subprocesses are dead
         for pidfile in self.pidfiles:
-            if not os.path.exists(pidfile): continue
+            if not os.path.exists(pidfile):
+                continue
             pid = open(pidfile).read()
-            if not pid: return
+            if not pid:
+                return
             pid = int(pid)
-            try: os.kill(pid, signal.SIGKILL)
-            except OSError: pass
+            try:
+                os.kill(pid, signal.SIGKILL)
+            except OSError:
+                pass
 
         # and clean up leftover pidfiles
         for pidfile in self.pidfiles:
@@ -442,6 +499,7 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
         # wait for a pidfile, and return the pid via a Deferred
         until = time.time() + 10
         d = defer.Deferred()
+
         def poll():
             if reactor.seconds() > until:
                 d.errback(RuntimeError("pidfile %s never appeared" % pidfile))
@@ -456,7 +514,7 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
                     d.callback(pid)
                     return
             reactor.callLater(0.01, poll)
-        poll() # poll right away
+        poll()  # poll right away
         return d
 
     def assertAlive(self, pid):
@@ -467,15 +525,17 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
 
     def assertDead(self, pid, timeout=5):
         log.msg("checking pid %r" % (pid,))
+
         def check():
             try:
                 os.kill(pid, 0)
             except OSError:
-                return True # dead
-            return False # alive
+                return True  # dead
+            return False  # alive
 
         # check immediately
-        if check(): return
+        if check():
+            return
 
         # poll every 100'th of a second; this allows us to test for
         # processes that have been killed, but where the signal hasn't
@@ -500,8 +560,8 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
 
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b,
-                scriptCommand('write_pidfile_and_sleep', pidfile),
-                self.basedir)
+                                  scriptCommand('write_pidfile_and_sleep', pidfile),
+                                  self.basedir)
         if interruptSignal is not None:
             s.interruptSignal = interruptSignal
         runproc_d = s.start()
@@ -509,7 +569,7 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
         pidfile_d = self.waitForPidfile(pidfile)
 
         def check_alive(pid):
-            self.pid = pid # for use in check_dead
+            self.pid = pid  # for use in check_dead
             # test that the process is still alive
             self.assertAlive(pid)
             # and tell the RunProcess object to kill it
@@ -521,6 +581,47 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
         runproc_d.addCallback(check_dead)
         return defer.gatherResults([pidfile_d, runproc_d])
 
+    def test_sigterm(self, interruptSignal=None):
+
+        # Tests that the process will receive SIGTERM if sigtermTimeout
+        # is not None
+        pidfile = self.newPidfile()
+        self.pid = None
+        b = FakeSlaveBuilder(False, self.basedir)
+        s = runprocess.RunProcess(b,
+                                  scriptCommand('write_pidfile_and_sleep', pidfile),
+                                  self.basedir, sigtermTime=1)
+        runproc_d = s.start()
+        pidfile_d = self.waitForPidfile(pidfile)
+        self.receivedSIGTERM = False
+
+        def check_alive(pid):
+            # Create a mock process that will check if we recieve SIGTERM
+            mock_process = Mock(wraps=s.process)
+            mock_process.pgid = None  # Skips over group SIGTERM
+            mock_process.pid = pid
+            process = s.process
+
+            def _mock_signalProcess(sig):
+                if sig == "TERM":
+                    self.receivedSIGTERM = True
+                process.signalProcess(sig)
+            mock_process.signalProcess = _mock_signalProcess
+            s.process = mock_process
+
+            self.pid = pid  # for use in check_dead
+            # test that the process is still alive
+            self.assertAlive(pid)
+            # and tell the RunProcess object to kill it
+            s.kill("diaf")
+        pidfile_d.addCallback(check_alive)
+
+        def check_dead(_):
+            self.failUnlessEqual(self.receivedSIGTERM, True)
+            self.assertDead(self.pid)
+        runproc_d.addCallback(check_dead)
+        return defer.gatherResults([pidfile_d, runproc_d])
+
     def test_pgroup_usePTY(self):
         return self.do_test_pgroup(usePTY=True)
 
@@ -531,10 +632,10 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
         # note that this configuration is not *used*, but that it is
         # still supported, and correctly fails to kill the child process
         return self.do_test_pgroup(usePTY=False, useProcGroup=False,
-                expectChildSurvival=True)
+                                   expectChildSurvival=True)
 
     def do_test_pgroup(self, usePTY, useProcGroup=True,
-                expectChildSurvival=False):
+                       expectChildSurvival=False):
         # test that a process group gets killed
         parent_pidfile = self.newPidfile()
         self.parent_pid = None
@@ -543,25 +644,28 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
 
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b,
-                scriptCommand('spawn_child', parent_pidfile, child_pidfile),
-                self.basedir,
-                usePTY=usePTY,
-                useProcGroup=useProcGroup)
+                                  scriptCommand('spawn_child', parent_pidfile, child_pidfile),
+                                  self.basedir,
+                                  usePTY=usePTY,
+                                  useProcGroup=useProcGroup)
         runproc_d = s.start()
 
         # wait for both processes to start up, then call s.kill
         parent_pidfile_d = self.waitForPidfile(parent_pidfile)
         child_pidfile_d = self.waitForPidfile(child_pidfile)
         pidfiles_d = defer.gatherResults([parent_pidfile_d, child_pidfile_d])
+
         def got_pids(pids):
             self.parent_pid, self.child_pid = pids
         pidfiles_d.addCallback(got_pids)
+
         def kill(_):
             s.kill("diaf")
         pidfiles_d.addCallback(kill)
 
         # check that both processes are dead after RunProcess is done
         d = defer.gatherResults([pidfiles_d, runproc_d])
+
         def check_dead(_):
             self.assertDead(self.parent_pid)
             if expectChildSurvival:
@@ -581,7 +685,7 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
         # note that this configuration is not *used*, but that it is
         # still supported, and correctly fails to kill the child process
         return self.do_test_double_fork(usePTY=False, useProcGroup=False,
-                expectChildSurvival=True)
+                                        expectChildSurvival=True)
 
     def do_test_double_fork(self, usePTY, useProcGroup=True,
                             expectChildSurvival=False):
@@ -595,25 +699,28 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
 
         b = FakeSlaveBuilder(False, self.basedir)
         s = runprocess.RunProcess(b,
-                scriptCommand('double_fork', parent_pidfile, child_pidfile),
-                self.basedir,
-                usePTY=usePTY,
-                useProcGroup=useProcGroup)
+                                  scriptCommand('double_fork', parent_pidfile, child_pidfile),
+                                  self.basedir,
+                                  usePTY=usePTY,
+                                  useProcGroup=useProcGroup)
         runproc_d = s.start()
 
         # wait for both processes to start up, then call s.kill
         parent_pidfile_d = self.waitForPidfile(parent_pidfile)
         child_pidfile_d = self.waitForPidfile(child_pidfile)
         pidfiles_d = defer.gatherResults([parent_pidfile_d, child_pidfile_d])
+
         def got_pids(pids):
             self.parent_pid, self.child_pid = pids
         pidfiles_d.addCallback(got_pids)
+
         def kill(_):
             s.kill("diaf")
         pidfiles_d.addCallback(kill)
 
         # check that both processes are dead after RunProcess is done
         d = defer.gatherResults([pidfiles_d, runproc_d])
+
         def check_dead(_):
             self.assertDead(self.parent_pid)
             if expectChildSurvival:
@@ -623,7 +730,9 @@ class TestPOSIXKilling(BasedirMixin, unittest.TestCase):
         d.addCallback(check_dead)
         return d
 
+
 class TestLogging(BasedirMixin, unittest.TestCase):
+
     def setUp(self):
         self.setUpBasedir()
 
@@ -655,7 +764,7 @@ class TestLogging(BasedirMixin, unittest.TestCase):
             {'stdout': 'hello '},
             {'stderr': 'DIEEEEEEE'},
             {'stdout': 'world'},
-            ])
+        ])
 
     def testSendChunked(self):
         b = FakeSlaveBuilder(False, self.basedir)
@@ -672,7 +781,9 @@ class TestLogging(BasedirMixin, unittest.TestCase):
         s._addToBuffers('stdout', data)
         self.failUnlessEqual(len(b.updates), 1)
 
+
 class TestLogFileWatcher(BasedirMixin, unittest.TestCase):
+
     def setUp(self):
         self.setUpBasedir()
 
